From b1d0840b986fe5dc9c13174e7218b660224b6c8a Mon Sep 17 00:00:00 2001
From: Tim van Dijen <tvdijen@gmail.com>
Date: Fri, 5 Jan 2018 01:13:51 +0100
Subject: [PATCH] Update IdP.php

---
 lib/SimpleSAML/IdP.php | 11 ++---------
 1 file changed, 2 insertions(+), 9 deletions(-)

diff --git a/lib/SimpleSAML/IdP.php b/lib/SimpleSAML/IdP.php
index 4789d6e4b..42a57ae9e 100644
--- a/lib/SimpleSAML/IdP.php
+++ b/lib/SimpleSAML/IdP.php
@@ -1,6 +1,5 @@
 <?php
 
-
 /**
  * IdP class.
  *
@@ -10,7 +9,6 @@
  */
 class SimpleSAML_IdP
 {
-
     /**
      * A cache for resolving IdP id's.
      *
@@ -18,7 +16,6 @@ class SimpleSAML_IdP
      */
     private static $idpCache = array();
 
-
     /**
      * The identifier for this IdP.
      *
@@ -26,7 +23,6 @@ class SimpleSAML_IdP
      */
     private $id;
 
-
     /**
      * The "association group" for this IdP.
      *
@@ -37,7 +33,6 @@ class SimpleSAML_IdP
      */
     private $associationGroup;
 
-
     /**
      * The configuration for this IdP.
      *
@@ -45,7 +40,6 @@ class SimpleSAML_IdP
      */
     private $config;
 
-
     /**
      * Our authsource.
      *
@@ -53,7 +47,6 @@ class SimpleSAML_IdP
      */
     private $authSource;
 
-
     /**
      * Initialize an IdP.
      *
@@ -341,12 +334,12 @@ class SimpleSAML_IdP
      *
      * @param array &$state The authentication request state.
      *
      * @throws SimpleSAML_Error_NoPassive If we were asked to do passive authentication.
      */
     private function authenticate(array &$state)
     {
         if (isset($state['isPassive']) && (bool) $state['isPassive']) {
-            throw new SimpleSAML_Error_NoPassive('Passive authentication not supported.');
+            throw new \SimpleSAML\Module\saml\Error\NoPassive('Passive authentication not supported.');
         }
 
         $this->authSource->login($state);
@@ -341,12 +334,12 @@ class SimpleSAML_IdP
      * @param array &$state The authentication request state.
      *
-     * @throws SimpleSAML_Error_NoPassive If we were asked to do passive authentication.
+     * @throws \SimpleSAML\Module\saml\Error\NoPassive If we were asked to do passive authentication.
      */
     private function authenticate(array &$state)
-- 
GitLab